"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.SkeldShipStatus = void 0;
const constant_1 = require("@skeldjs/constant");
const InnerShipStatus_1 = require("./InnerShipStatus");
const systems_1 = require("../systems");
const AutoOpenDoor_1 = require("../misc/AutoOpenDoor");
/**
 * Represents a room object for the The Skeld map.
 *
 * See {@link ShipStatusEvents} for events to listen to.
 */
class SkeldShipStatus extends InnerShipStatus_1.InnerShipStatus {
    constructor(room, spawnType, netid, ownerid, flags, data) {
        super(room, spawnType, netid, ownerid, flags, data);
    }
    getComponent(component) {
        if (component === SkeldShipStatus) {
            return this.components[0];
        }
        return undefined;
    }
    async HandleRpc(rpc) {
        switch (rpc.messageTag) {
            case constant_1.RpcMessageTag.CloseDoorsOfType:
                await this._handleCloseDoorsOfType(rpc);
                break;
            default:
                await super.HandleRpc(rpc);
                break;
        }
    }
    async _handleCloseDoorsOfType(rpc) {
        const doorsinRoom = SkeldShipStatus.roomDoors[rpc.systemid];
        for (const doorId of doorsinRoom) {
            this.systems[constant_1.SystemType.Doors].closeDoor(doorId);
        }
    }
    Setup() {
        this.systems = {
            [constant_1.SystemType.Reactor]: new systems_1.ReactorSystem(this, {
                timer: 10000,
                completed: new Set,
            }),
            [constant_1.SystemType.Electrical]: new systems_1.SwitchSystem(this, {
                expected: [false, false, false, false, false],
                actual: [false, false, false, false, false],
                brightness: 255,
            }),
            [constant_1.SystemType.O2]: new systems_1.LifeSuppSystem(this, {
                timer: 10000,
                completed: new Set,
            }),
            [constant_1.SystemType.MedBay]: new systems_1.MedScanSystem(this, {
                queue: [],
            }),
            [constant_1.SystemType.Security]: new systems_1.SecurityCameraSystem(this, {
                players: new Set,
            }),
            [constant_1.SystemType.Communications]: new systems_1.HudOverrideSystem(this, {
                sabotaged: false,
            }),
            [constant_1.SystemType.Doors]: new systems_1.AutoDoorsSystem(this, {
                dirtyBit: 0,
                doors: [],
            }),
            [constant_1.SystemType.Sabotage]: new systems_1.SabotageSystem(this, {
                cooldown: 0,
            }),
        };
        const autodoorsystem = this.systems[constant_1.SystemType.Doors];
        autodoorsystem.doors = [
            new AutoOpenDoor_1.AutoOpenDoor(autodoorsystem, 0, true),
            new AutoOpenDoor_1.AutoOpenDoor(autodoorsystem, 1, true),
            new AutoOpenDoor_1.AutoOpenDoor(autodoorsystem, 2, true),
            new AutoOpenDoor_1.AutoOpenDoor(autodoorsystem, 3, true),
            new AutoOpenDoor_1.AutoOpenDoor(autodoorsystem, 4, true),
            new AutoOpenDoor_1.AutoOpenDoor(autodoorsystem, 5, true),
            new AutoOpenDoor_1.AutoOpenDoor(autodoorsystem, 6, true),
            new AutoOpenDoor_1.AutoOpenDoor(autodoorsystem, 7, true),
            new AutoOpenDoor_1.AutoOpenDoor(autodoorsystem, 8, true),
            new AutoOpenDoor_1.AutoOpenDoor(autodoorsystem, 9, true),
            new AutoOpenDoor_1.AutoOpenDoor(autodoorsystem, 10, true),
            new AutoOpenDoor_1.AutoOpenDoor(autodoorsystem, 11, true),
            new AutoOpenDoor_1.AutoOpenDoor(autodoorsystem, 12, true),
            new AutoOpenDoor_1.AutoOpenDoor(autodoorsystem, 13, true),
        ];
    }
}
exports.SkeldShipStatus = SkeldShipStatus;
SkeldShipStatus.roomDoors = {
    [constant_1.SystemType.Storage]: [1, 7, 12],
    [constant_1.SystemType.Cafeteria]: [0, 3, 8],
    [constant_1.SystemType.UpperEngine]: [2, 5],
    [constant_1.SystemType.Electrical]: [9],
    [constant_1.SystemType.MedBay]: [10],
    [constant_1.SystemType.Security]: [6],
    [constant_1.SystemType.LowerEngine]: [4, 11]
};
//# sourceMappingURL=SkeldShipStatus.js.map