import { HazelReader, HazelWriter } from "@skeldjs/util";
import { SystemType } from "@skeldjs/constant";
import { BasicEvent, EventEmitter } from "@skeldjs/events";
import { RepairSystemMessage } from "@skeldjs/protocol";
import { InnerShipStatus } from "../objects";
import { PlayerData } from "../PlayerData";
import { SystemStatusEvents } from "./events";
import { Hostable } from "../Hostable";
export declare class SystemStatus<DataT = any, T extends SystemStatusEvents = SystemStatusEvents, RoomType extends Hostable<any> = Hostable<any>> extends EventEmitter<T> {
    protected ship: InnerShipStatus<RoomType>;
    static systemType: SystemType;
    systemType: SystemType;
    private _dirty;
    constructor(ship: InnerShipStatus<RoomType>, data?: HazelReader | DataT);
    get dirty(): boolean;
    set dirty(isDirty: boolean);
    protected patch(data: DataT): void;
    /**
     * Whether or not this system is sabotaged.
     */
    get sabotaged(): boolean;
    /**
     * Return the room that this system belongs to.
     */
    get room(): RoomType;
    emit<Event extends BasicEvent>(event: Event): Promise<Event>;
    Deserialize(reader: HazelReader, spawn: boolean): void;
    Serialize(writer: HazelWriter, spawn: boolean): void;
    HandleRepair(player: PlayerData, amount: number, rpc: RepairSystemMessage | undefined | undefined): Promise<void>;
    Detoriorate(delta: number): void;
    HandleSabotage(player: PlayerData, rpc: RepairSystemMessage | undefined): Promise<void>;
    /**
     * Fully repair this system.
     */
    repair(): Promise<void>;
    /**
     * Sabotage this system.
     */
    sabotage(): Promise<void>;
    protected _sendRepair(amount: number): Promise<void>;
}
